@@ -51,7 +51,7 @@ Lum::Object* PackageDetails::GetTextField(const std::wstring& text) const
   return t;
 }
 
-void PackageDetails::PreInit()
+Lum::Object* PackageDetails::GetContent()
 {
   Lum::Edit::Edit             *edit;
   Lum::Edit::Text             *editContent;
@@ -105,11 +105,13 @@ void PackageDetails::PreInit()
   headerList->Append(header);
 
   headers=new Lum::Model::HeaderImpl();
-  headers->AddColumn(L"Data",Lum::Base::Size::stdCharWidth,15);
-  headers->AddColumn(L"Value",Lum::Base::Size::stdCharWidth,20,true);
+  headers->AddColumn(L"Data",Lum::Base::Size::stdCharWidth,10);
+  headers->AddColumn(L"Value",Lum::Base::Size::stdCharWidth,25,true);
 
   table=new Lum::Table();
   table->SetFlex(true,true);
+  table->SetMinWidth(Lum::Base::Size::stdCharWidth,35);
+  table->SetMinHeight(Lum::Base::Size::stdCharHeight,8);
   table->SetShowHeader(true);
   table->GetTableView()->SetAutoHSize(true);
   table->GetTableView()->SetAutoFitColumns(true);
@@ -124,14 +126,17 @@ void PackageDetails::PreInit()
 
   edit=new Lum::Edit::Edit();
   edit->SetFlex(true,true);
-  edit->SetMinWidth(Lum::Base::Size::stdCharWidth,40);
-  edit->SetMinHeight(Lum::Base::Size::stdCharHeight,5);
   edit->SetConfig(Lum::Edit::Config::GetDefaultConfig());
   edit->SetColorSheme(Lum::Edit::ColorSheme::GetDefaultColorSheme());
-  edit->SetFont(Lum::OS::display->GetFont());
+  if (Lum::OS::display->GetSize()<Lum::OS::Display::sizeNormal) {
+    edit->SetFont(Lum::OS::display->GetFont(70));
+  }
+  else {
+    edit->SetFont(Lum::OS::display->GetFont());
+  }
   edit->SetModel(editContent);
 
-  tab->Add(L"Description",Lum::View::Create(edit,true,true));
+  tab->Add(L"Descr.",Lum::View::Create(edit,true,true));
 
   table=new Lum::Table();
   table->SetFlex(true,true);
@@ -150,22 +155,21 @@ void PackageDetails::PreInit()
 
   edit=new Lum::Edit::Edit();
   edit->SetFlex(true,true);
-  edit->SetMinWidth(Lum::Base::Size::stdCharWidth,40);
-  edit->SetMinHeight(Lum::Base::Size::stdCharHeight,5);
   edit->SetConfig(Lum::Edit::Config::GetDefaultConfig());
   edit->SetColorSheme(Lum::Edit::ColorSheme::GetDefaultColorSheme());
   edit->SetFont(Lum::OS::display->GetFont());
   edit->SetModel(editContent);
 
-  tab->Add(L"Dependencies",Lum::View::Create(edit,true,true));
+  tab->Add(L"Deps.",Lum::View::Create(edit,true,true));
 
   vPanel->Add(tab);
-  vPanel->AddSpace();
-  vPanel->Add(Lum::ButtonRow::CreateClose(GetClosedAction(),true,false));
 
-  SetMain(vPanel);
+  return vPanel;
+}
 
-  Lum::Dialog::PreInit();
+void PackageDetails::GetActions(std::vector<Lum::Dlg::ActionInfo>& actions)
+{
+  Lum::Dlg::ActionDialog::CreateActionInfosClose(actions,GetClosedAction());
 }
 
 void PackageDetails::Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg)
